# -*- coding: utf-8 -*-
from django.core.management.base import NoArgsCommand

from planet.tasks import process_feed
from planet.models import Feed
from planet.signals import feeds_updated


class Command(NoArgsCommand):
    help = "Update all feeds"

    def handle(self, *args, **options):
        for feed_url in Feed.site_objects.all().values_list("url", flat=True):
            # process feed in create-mode
            self.stdout.write("Scheduling feed with URL=%s..." % feed_url)
            process_feed.delay(feed_url, create=False)

        feeds_updated.send(sender=self, instance=self)



# -*- coding: utf-8 -*-
import django

from django.db import models
from django.conf import settings


class FeedManager(models.Manager):
    """
    """
    def get_queryset(self):
        qs = super(FeedManager, self).get_queryset()
        return qs.filter(site=settings.SITE_ID, is_active=True)

    if django.VERSION < (1, 6):
        get_query_set = get_queryset


class FeedLinkManager(models.Manager):
    """
    """
    def get_queryset(self):
        qs = super(FeedLinkManager, self).get_queryset()
        return qs.filter(feed__site=settings.SITE_ID)

    if django.VERSION < (1, 6):
        get_query_set = get_queryset


class BlogManager(models.Manager):
    """
    """
    def get_queryset(self):
        qs = super(BlogManager, self).get_queryset()
        return qs.filter(feed__site=settings.SITE_ID).distinct()

    if django.VERSION < (1, 6):
        get_query_set = get_queryset


class GeneratorManager(models.Manager):
    """
    """
    def get_queryset(self):
        qs = super(GeneratorManager, self).get_queryset()
        return qs.filter(feed__site=settings.SITE_ID).distinct()

    if django.VERSION < (1, 6):
        get_query_set = get_queryset


class AuthorManager(models.Manager):
    """
    """
    def get_queryset(self):
        qs = super(AuthorManager, self).get_queryset()
        return qs.filter(post__feed__site=settings.SITE_ID).distinct()

    if django.VERSION < (1, 6):
        get_query_set = get_queryset


class PostManager(models.Manager):
    """
    """
    def get_queryset(self):
        qs = super(PostManager, self).get_queryset()
        return qs.filter(feed__site=settings.SITE_ID).distinct()

    if django.VERSION < (1, 6):
        get_query_set = get_queryset


class PostLinkManager(models.Manager):
    """
    """
    def get_queryset(self):
        qs = super(PostLinkManager, self).get_queryset()
        return qs.filter(post__feed__site=settings.SITE_ID).distinct()

    if django.VERSION < (1, 6):
        get_query_set = get_queryset


class EnclosureManager(models.Manager):
    """
    """
    def get_queryset(self):
        qs = super(EnclosureManager, self).get_queryset()
        return qs.filter(post__feed__site=settings.SITE_ID).distinct()

    if django.VERSION < (1, 6):
        get_query_set = get_queryset



import factory

from factory.fuzzy import FuzzyText

from django.contrib.sites.models import Site

from planet.models import (
    Blog, Feed, Post, Generator, PostAuthorData,
    PostLink, Enclosure, FeedLink, Author, Category
)


class SiteFactory(factory.DjangoModelFactory):
    class Meta:
        model = Site

    domain = factory.Sequence(lambda n: u'example-site-{}.com'.format(n))


class BlogFactory(factory.DjangoModelFactory):
    class Meta:
        model = Blog

    title = factory.Sequence(lambda n: u'blog-{}'.format(n))
    url = factory.LazyAttribute(lambda obj: u'http://{}.blogspot.com/'.format(obj.title))
    owner = None


class GeneratorFactory(factory.DjangoModelFactory):
    class Meta:
        model = Generator

    name = factory.Sequence(lambda n: u'generator-{}'.format(n))


class CategoryFactory(factory.DjangoModelFactory):
    class Meta:
        model = Category

    title = factory.Sequence(lambda n: u'Category #{}'.format(n))


class FeedFactory(factory.DjangoModelFactory):
    class Meta:
        model = Feed

    title = factory.Sequence(lambda n: u'Feed-{}'.format(n))
    blog = factory.SubFactory(BlogFactory)
    url = factory.LazyAttribute(lambda obj: '{}feed-{}.rss'.format(obj.blog.url, obj.title))
    generator = factory.SubFactory(GeneratorFactory)
    language = "en"
    site = factory.SubFactory(SiteFactory)


class AuthorFactory(factory.DjangoModelFactory):
    class Meta:
        model = Author

    name = factory.Sequence(lambda n: u'Author #{}'.format(n))
    email = factory.LazyAttribute(lambda obj: u'{}@gmail.com'.format(obj.name))


class PostFactory(factory.DjangoModelFactory):
    class Meta:
        model = Post

    title = factory.Sequence(lambda n: u'Post Title #{}'.format(n))
    feed = factory.SubFactory(FeedFactory)
    url = factory.LazyAttribute(lambda obj: u'post-{}.html'.format(obj.feed.blog.url))
    guid = factory.Sequence(lambda n: u'GUID-{}'.format(n))
    content = FuzzyText(length=200)

    @factory.post_generation
    def authors(self, create, extracted, **kwargs):
        if not create:
            # Simple build, do nothing.
            return

        if extracted:
            # A list of groups were passed in, use them
            for author in extracted:
                PostAuthorDataFactory.create(post=self, author=author)


class PostAuthorDataFactory(factory.DjangoModelFactory):
    class Meta:
        model = PostAuthorData

    post = factory.SubFactory(PostFactory)
    author = factory.SubFactory(AuthorFactory)


class PostLinkFactory(factory.DjangoModelFactory):
    class Meta:
        model = PostLink

    title = factory.Sequence(lambda n: u'post-link-{}'.format(n))
    post = factory.SubFactory(PostFactory)
    rel = "alternative"
    mime_type = "application/html"
    link = factory.LazyAttribute(lambda obj: u'{}post-links/{}.html'.format(obj.feed.blog.url, obj.title))


class FeedLinkFactory(factory.DjangoModelFactory):
    class Meta:
        model = FeedLink

    feed = factory.SubFactory(FeedFactory)
    rel = "alternative"
    mime_type = "application/html"
    link = factory.LazyAttribute(lambda obj: u'{}feed-links/{}.rss'.format(obj.feed.blog.url, obj.feed.title))


class EnclosureFactory(factory.DjangoModelFactory):
    class Meta:
        model = Enclosure

    title = factory.Sequence(lambda n: u'enclosure-#{}'.format(n))
    post = factory.SubFactory(PostFactory)
    mime_type = "image/png"
    link = factory.Sequence(lambda obj: u'{}post-{}/image-{}.png'.format(obj.post.feed.blog.url, obj.post.title, obj.title))
    Length = 1024



# -*- coding: utf-8 -*-
from django.core.urlresolvers import reverse, reverse_lazy
from django.forms import ValidationError
from django.http import HttpResponseRedirect
from django.shortcuts import render_to_response, get_object_or_404, redirect
from django.template import RequestContext
from django.utils.translation import ugettext_lazy as _
from django.views.generic import ListView
from django.views.generic.detail import SingleObjectMixin
from django.views.generic.edit import CreateView, DeleteView
from django.http import Http404

from planet.models import Blog, Feed, Author, Post
from planet.forms import SearchForm

from tagging.models import Tag, TaggedItem


def index(request):
    posts = Post.site_objects.all().order_by("-date_modified")

    return render_to_response("planet/posts/list.html", {"posts": posts},
        context_instance=RequestContext(request))


def blogs_list(request):
    blogs_list = Blog.site_objects.all()

    return render_to_response("planet/blogs/list.html",
        {"blogs_list": blogs_list}, context_instance=RequestContext(request))


def blog_detail(request, blog_id, slug=None):
    blog = get_object_or_404(Blog, pk=blog_id)

    if slug is None:
        return redirect(blog, permanent=True)

    posts = Post.site_objects.filter(feed__blog=blog).order_by("-date_modified")

    return render_to_response("planet/blogs/detail.html",
                              {"blog": blog, "posts": posts},
        context_instance=RequestContext(request))


def feeds_list(request):
    feeds_list = Feed.site_objects.all()

    return render_to_response("planet/feeds/list.html",
        {"feeds_list": feeds_list}, context_instance=RequestContext(request))


def feed_detail(request, feed_id, tag=None, slug=None):
    feed = get_object_or_404(Feed, pk=feed_id)

    if not slug:
        return redirect(feed, permanent=True)

    if tag:
        tag = get_object_or_404(Tag, name=tag)

        posts = TaggedItem.objects.get_by_model(
            Post.site_objects, tag).filter(feed=feed).order_by("-date_modified")
    else:
        posts = Post.site_objects.filter(feed=feed).order_by("-date_modified")

    return render_to_response("planet/feeds/detail.html",
        {"feed": feed, "posts": posts, "tag": tag},
        context_instance=RequestContext(request))


def authors_list(request):
    authors = Author.site_objects.all()

    return render_to_response("planet/authors/list.html",
        {"authors_list": authors},
        context_instance=RequestContext(request))


def author_detail(request, author_id, tag=None, slug=None):
    author = get_object_or_404(Author, pk=author_id)

    if not slug:
        return redirect(author, permanent=True)

    if tag:
        tag = get_object_or_404(Tag, name=tag)

        posts = TaggedItem.objects.get_by_model(Post.site_objects, tag).filter(
            authors=author).order_by("-date_modified")
    else:
        posts = Post.site_objects.filter(
            authors=author).order_by("-date_modified")

    return render_to_response("planet/authors/detail.html",
        {"author": author, "posts": posts, "tag": tag},
        context_instance=RequestContext(request))


def posts_list(request):
    posts = Post.site_objects.all().select_related("feed", "blog", "authors")\
        .order_by("-date_modified")

    return render_to_response("planet/posts/list.html", {"posts": posts},
        context_instance=RequestContext(request))


def post_detail(request, post_id, slug=None):
    post = get_object_or_404(
        Post.objects.select_related("feed", "authors", "blog"), pk=post_id)

    if not slug:
        return redirect(post, permanent=True)

    return render_to_response("planet/posts/detail.html", {"post": post},
        context_instance=RequestContext(request))


def tag_detail(request, tag):
    tag = get_object_or_404(Tag, name=tag)

    posts = TaggedItem.objects.get_by_model(
        Post.site_objects, tag).order_by("-date_modified")

    return render_to_response("planet/tags/detail.html", {"posts": posts,
        "tag": tag}, context_instance=RequestContext(request))


def tag_authors_list(request, tag):
    tag = get_object_or_404(Tag, name=tag)

    posts_list = TaggedItem.objects.get_by_model(Post.site_objects, tag)

    authors = set()
    for post in posts_list:
        for author in post.authors.all():
            authors.add(author)

    return render_to_response("planet/authors/list_for_tag.html",
        {"authors": list(authors), "tag": tag},
        context_instance=RequestContext(request))


def tag_feeds_list(request, tag):
    tag = get_object_or_404(Tag, name=tag)

    post_ids = TaggedItem.objects.get_by_model(Post.site_objects, tag
        ).values_list("id", flat=True)

    feeds_list = Feed.site_objects.filter(post__in=post_ids).distinct()

    return render_to_response("planet/feeds/list_for_tag.html",
        {"feeds_list": feeds_list, "tag": tag},
        context_instance=RequestContext(request))


def tags_cloud(request, min_posts_count=1):

    tags_cloud = Tag.objects.cloud_for_model(Post)

    return render_to_response("planet/tags/cloud.html",
        {"tags_cloud": tags_cloud}, context_instance=RequestContext(request))


def foaf(request):
    # TODO: use http://code.google.com/p/django-foaf/ instead of this
    feeds = Feed.site_objects.all().select_related("blog")

    return render_to_response("planet/microformats/foaf.xml", {"feeds": feeds},
        context_instance=RequestContext(request), content_type="text/xml")


def opml(request):
    feeds = Feed.site_objects.all().select_related("blog")

    return render_to_response("planet/microformats/opml.xml", {"feeds": feeds},
        context_instance=RequestContext(request), content_type="text/xml")


def search(request):
    if request.method == "GET" and request.GET.get("search") == "go":
        search_form = SearchForm(request.GET)

        if search_form.is_valid():
            query = search_form.cleaned_data["q"]

            if search_form.cleaned_data["w"] == "posts":
                params_dict = {"title__icontains": query}

                posts = Post.site_objects.filter(**params_dict
                    ).distinct().order_by("-date_modified")

                return render_to_response("planet/posts/list.html",
                    {"posts": posts}, context_instance=RequestContext(request))

            elif search_form.cleaned_data["w"] == "tags":
                params_dict = {"name__icontains": query}

                tags_list = Tag.objects.filter(**params_dict
                    ).distinct().order_by("name")

                return render_to_response("planet/tags/list.html",
                    {"tags_list": tags_list},
                    context_instance=RequestContext(request))

            elif search_form.cleaned_data["w"] == "blogs":
                params_dict = {"title__icontains": query}

                blogs_list = Blog.site_objects.filter(**params_dict
                    ).order_by("title")

                return render_to_response("planet/blogs/list.html",
                    {"blogs_list": blogs_list},
                    context_instance=RequestContext(request))

            elif search_form.cleaned_data["w"] == "feeds":
                params_dict = {"title__icontains": query}

                feeds_list = Feed.site_objects.filter(**params_dict
                    ).order_by("title")

                return render_to_response("planet/feeds/list.html",
                    {"feeds_list": feeds_list},
                    context_instance=RequestContext(request))

            elif search_form.cleaned_data["w"] == "authors":
                params_dict = {"name__icontains": query}

                authors_list = Author.site_objects.filter(**params_dict
                    ).order_by("name")

                return render_to_response("planet/authors/list.html",
                    {"authors_list": authors_list},
                    context_instance=RequestContext(request))

            else:
                return HttpResponseRedirect(reverse("planet_post_list"))

        else:
            return HttpResponseRedirect(reverse("planet_post_list"))

    else:
        return HttpResponseRedirect(reverse("planet_post_list"))


class FeedAddView(CreateView):
    model = Feed
    fields = ["url"]
    template_name = 'planet/feeds/add.html'
    success_message = _("Feed with url=%(url)s was created successfully")

    def clean_url(self):
        url = self.cleaned_data['url']

        if Feed.objects.filter(url=url).count() > 0:
            raise ValidationError(_('A feed with this URL already exists.'))

        return url

    def form_valid(self, form):
        feed = form.save()

        if self.request.user.is_authenticated():
            feed.blog.owner = self.request.user
            feed.blog.save()

        self.object = feed

        return HttpResponseRedirect(reverse("planet_index"))


class BlogListByUserView(ListView):
    template_name = 'planet/blogs/list_by_user.html'
    model = Blog

    def get_queryset(self):
        return Blog.objects.filter(owner=self.request.user)


class OwnedObjectMixin(SingleObjectMixin):
    """
    An object that needs to verify current user ownership
    before allowing manipulation.

    From https://github.com/PyAr/pyarweb/blob/b4095c5c1b474a207e45918683de400974f6a739/community/views.py#L43
    """

    def get_object(self, *args, **kwargs):
        obj = super(OwnedObjectMixin, self).get_object(*args, **kwargs)

        try:
            if not obj.owner == self.request.user:
                raise Http404()
        except AttributeError:
            pass

        return obj


class BlogDeleteView(DeleteView, OwnedObjectMixin):
    template_name = 'planet/blogs/confirm_delete.html'
    model = Blog
    success_url = reverse_lazy('planet_blog_list_by_user')



# -*- coding: utf-8 -*-

from __future__ import absolute_import

from celery import task
from datetime import datetime
from hashlib import md5
try:
    from urlparse import urlparse
except ImportError:
    from urllib.parse import urlparse

import feedparser
import time
import mimetypes
from bs4 import BeautifulSoup

from django.conf import settings
from django.contrib.sites.models import Site
from django.contrib.auth import get_user_model

from tagging.models import Tag

from planet.models import (Blog, Generator, Feed, FeedLink, Post, PostLink,
                           Author, PostAuthorData, Enclosure, Category)
from planet.signals import feeds_updated
from planet.signals import post_created


class PostAlreadyExists(Exception):
    pass


@task
def process_feed(feed_url, owner_id=None, create=False, category_title=None):
    """
    Stores a feed, its related data, its entries and their related data.
    If create=True then it creates the feed, otherwise it only stores new
    entries  and their related data.
    """

    print("[process_feed] URL={}".format(feed_url))

    def normalize_tag(tag):
        """
        converts things like "-noise-" to "noise" and "- noise -" to "noise"
        """
        if tag.startswith("-"):
            tag = tag[1:]
        if tag.endswith("-"):
            tag = tag[:-1]

        # fix for HTML entities
        tag = BeautifulSoup(tag).prettify(formatter="html")
        tag = tag.strip().lower()
        return tag

    try:
        USER_AGENT = settings.PLANET["USER_AGENT"]
    except (KeyError, AttributeError):
        print(
            """Please set PLANET = {" USER_AGENT": <string>} in your settings.py""")
        exit(0)

    feed_url = str(feed_url).strip()

    try:
        planet_feed = Feed.objects.get(url=feed_url)
    except Feed.DoesNotExist:
        planet_feed = None

    print("*" * 20)
    print("Feed: {}".format(feed_url))

    if create and planet_feed:
        # can't create it due to it already exists
        print("This feed already exists!")
        exit(0)

    if not create and not planet_feed:
        # can't update it due to it does not exist
        print("This feed does not exist!")
        exit(0)

    # retrieve and parse feed using conditional GET method
    if not create:
        modified = datetime.timetuple(planet_feed.last_modified)
        etag = planet_feed.etag
        # update last checked datetime
        planet_feed.last_checked = datetime.now()
        planet_feed.save()
    else:
        modified = etag = None

    document = feedparser.parse(feed_url, agent=USER_AGENT,
                                modified=modified, etag=etag)

    current_site = Site.objects.get(pk=settings.SITE_ID)

    if create:
        # then create blog, feed, generator, feed links and feed tags
        title = document.feed.get("title", "--")
        subtitle = document.feed.get("subtitle")
        blog_url = document.feed.get("link")
        rights = document.feed.get("rights") or document.feed.get("license")
        info = document.feed.get("info")
        try:
            guid = unicode(md5(document.feed.get("link")).hexdigest())
        except NameError:
            guid = md5(document.feed.get("link").encode('utf-8')).hexdigest()
        image_url = document.feed.get("image", {}).get("href")
        icon_url = document.feed.get("icon")
        language = document.feed.get("language")
        etag = document.get("etag", '')

        updated_parsed = document.get("updated_parsed")
        if updated_parsed:
            last_modified = datetime.fromtimestamp(time.mktime(updated_parsed))
        else:
            last_modified = datetime.now()

        feed_links = document.feed.get("links", [])
        if not blog_url:
            link = [item for item in feed_links if item["rel"] == "alternate"]
            if link:
                blog_url = link[0]["href"]

        User = get_user_model()
        try:
            owner = User.objects.get(pk=owner_id)
        except User.DoesNotExist:
            owner = None

        blog, created = Blog.objects.get_or_create(
            url=blog_url, defaults={"title": title}, owner=owner)

        generator_dict = document.feed.get("generator_detail", {})

        if generator_dict:
            generator, created = Generator.objects.get_or_create(
                name=generator_dict.get("name", "--"),
                link=generator_dict.get("link"),
                version=generator_dict.get("version"))
        else:
            generator = None

        if category_title:
            # TODO: site_objects!
            category = Category.objects.get(title=category_title)
        else:
            category = None

        planet_feed = Feed(title=title, subtitle=subtitle, blog=blog,
                           url=feed_url, rights=rights, info=info, guid=guid,
                           image_url=image_url, icon_url=icon_url, language=language,
                           etag=etag, last_modified=last_modified, generator=generator,
                           is_active=True, last_checked=datetime.now(),
                           site=current_site, category=category
                           )
        planet_feed.save()

        for tag_dict in document.feed.get("tags", []):
            name = tag_dict.get("term")

        for link_dict in feed_links:
            feed_link, created = FeedLink.objects.get_or_create(
                feed=planet_feed,
                rel=link_dict.get("rel", "--"),
                mime_type=link_dict.get("type", "text/html"),
                link=link_dict.get("href", blog_url)
            )

    entries = []

    total_results = int(
        document.feed.get("opensearch_totalresults", len(document.entries)))
    items_per_page = int(document.feed.get("opensearch_itemsperpage", 25))
    new_posts_count = 0

    if total_results == 0:
        print("No entries to store. status: {} {}".format(
            document.get("status"), document.get("debug_message")))
    else:
        print("Entries total count: {}".format(total_results))
        stop_retrieving = False
        while (total_results > len(entries)) and not stop_retrieving:

            # retrieve and store feed posts
            entries.extend(document.entries)
            print("Processing {} entries".format(len(document.entries)))

            for entry in document.entries:
                title = entry.get("title", "")
                url = entry.get("link")
                try:
                    guid = unicode(md5(entry.get("link")).hexdigest())
                except NameError:
                    guid = md5(entry.get("link").encode('utf-8')).hexdigest()
                content = entry.get('description') or entry.get(
                    "content", [{"value": ""}])[0]["value"]
                comments_url = entry.get("comments")
                date_modified = entry.get("updated_parsed") or\
                    entry.get("published_parsed")
                try:
                    date_modified = datetime.fromtimestamp(
                        time.mktime(date_modified))
                except Exception:
                    date_modified = planet_feed.last_modified or datetime.now()

                try:
                    if len(Post.objects.filter(url=url, guid=guid)):
                        raise PostAlreadyExists
                    post = Post(title=title, url=url, guid=guid, content=content,
                                comments_url=comments_url, date_modified=date_modified,
                                feed=planet_feed)
                    # To have the feed entry in the pre_save signal
                    post.entry = entry
                    post.save()
                except PostAlreadyExists:
                    print("Skipping post {} ({}) because already exists"
                          .format(guid, url))
                    if not create:
                        # if it is in update-mode then stop retrieving when
                        # it finds repeated posts
                        stop_retrieving = True
                else:
                    new_posts_count += 1
                    # create post tags...
                    for tag_dict in entry.get("tags", []):
                        tag_name = tag_dict.get(
                            "term") or tag_dict.get("label")
                        tag_name = normalize_tag(tag_name)

                        if len(tag_name) > 50:
                            continue

                        try:
                            if "/" in tag_name:
                                # For path based categories
                                for subtag in tag_name.split("/"):
                                    if subtag:
                                        # empty string if starts/ends with
                                        # slash
                                        Tag.objects.add_tag(
                                            post, '"%s"' % subtag)
                            else:
                                Tag.objects.add_tag(post, '"%s"' % tag_name)
                        except AttributeError as e:
                            print("Ignoring tag error: {}".format(e))
                    # create post links...
                    for link_dict in entry.get("links", []):
                        post_link, created = PostLink.objects.get_or_create(
                            post=post,
                            rel=link_dict.get("rel", "--"),
                            mime_type=link_dict.get("type", "text/html"),
                            link=link_dict.get("href", "--"),
                            title=link_dict.get("title", "--")
                        )

                    # create and store enclosures...
                    if entry.get('media_thumbnail', False):
                        try:
                            media_url = entry.get('media_thumbnail').href
                            media_list = [{"url": media_url}]
                        except AttributeError:
                            media_list = entry.get(
                                'media_thumbnail', [{"url": None}])

                        for media in media_list:
                            media_url = media["url"]
                            mime_type, enc = mimetypes.guess_type(
                                urlparse(media_url).path)

                            post_enclosure, created = Enclosure.objects.get_or_create(
                                post=post,
                                length=0,
                                mime_type=mime_type,
                                link=media_url
                            )

                    for enclosure_dict in entry.get("enclosures", []):
                        post_enclosure = Enclosure(
                            post=post,
                            length=enclosure_dict.get("length", 0),
                            mime_type=enclosure_dict.get("type", ""),
                            link=enclosure_dict.get("href")
                        )
                        post_enclosure.save()

                    # create and store author...
                    author_dict = entry.get("author_detail")

                    if author_dict:
                        author, created = Author.objects.get_or_create(
                            name=author_dict.get("name", ""),
                            email=author_dict.get("email", ""),
                            profile_url=author_dict.get("href")
                        )
                        try:
                            PostAuthorData.objects.get(
                                author=author, post=post)
                        except PostAuthorData.DoesNotExist:
                            pad = PostAuthorData(author=author, post=post)
                            pad.save()

                    # create and store contributors...
                    for contributor_dict in entry.get("contributors", []):
                        contributor, created = Author.objects.get_or_create(
                            name=author_dict.get("name", ""),
                            email=author_dict.get("email", ""),
                            profile_url=contributor_dict.get("href")
                        )
                        try:
                            PostAuthorData.objects.get(
                                author=contributor, post=post)
                        except PostAuthorData.DoesNotExist:
                            pad = PostAuthorData(author=contributor, post=post,
                                                 is_contributor=True)
                            pad.save()

                    # We send a post_created signal
                    print('post_created.send(sender=post)', post)
                    post_created.send(sender=post, instance=post)

            if not stop_retrieving:
                opensearch_url = "{}?start-index={}&max-results={}".format(
                    feed_url, len(entries) + 1, items_per_page)

                print("retrieving {}...".format(opensearch_url))
                document = feedparser.parse(opensearch_url, agent=USER_AGENT)

        if new_posts_count:
            # update last modified datetime
            planet_feed.last_modified = datetime.now()
            planet_feed.save()
        print("{} posts were created. Done.".format(new_posts_count))

    return new_posts_count


@task(ignore_results=True)
def update_feeds():
    """
    Task for running on celery beat!

    CELERYBEAT_SCHEDULE = {
        'update_feeds': {
            'task': 'planet.tasks.update_feeds',
            'schedule': timedelta(hours=1)
        }
    }
    """

    for feed_url in Feed.site_objects.all().values_list("url", flat=True):
        print("Scheduling feed URL={}...".format(feed_url))
        process_feed.delay(feed_url, create=False)
        print("Done!")

    feeds_updated.send(sender=None, instance=None)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0001_initial'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Author',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(db_index=True, max_length=255, null=True, verbose_name='Name', blank=True)),
                ('email', models.EmailField(db_index=True, max_length=75, verbose_name='Author email', blank=True)),
                ('profile_url', models.URLField(null=True, verbose_name='Profile URL', blank=True)),
            ],
            options={
                'ordering': ('name', 'email'),
                'verbose_name': 'Author',
                'verbose_name_plural': 'Authors',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Blog',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('title', models.CharField(db_index=True, max_length=255, verbose_name='title', blank=True)),
                ('url', models.URLField(unique=True, verbose_name='Url', db_index=True)),
                ('date_created', models.DateTimeField(auto_now_add=True, verbose_name='Date created')),
                ('owner', models.ForeignKey(blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'ordering': ('title', 'url'),
                'verbose_name': 'Blog',
                'verbose_name_plural': 'Blogs',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Category',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('title', models.CharField(unique=True, max_length=100, verbose_name='Category Title')),
                ('date_created', models.DateField(auto_now_add=True, verbose_name='Date created')),
            ],
            options={
                'ordering': ('title', 'date_created'),
                'verbose_name': 'Feed Category',
                'verbose_name_plural': 'Feed Categories',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Enclosure',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('length', models.CharField(max_length=20, verbose_name='Length')),
                ('mime_type', models.CharField(max_length=50, verbose_name='MIME type', db_index=True)),
                ('link', models.URLField(max_length=500, verbose_name='Url', db_index=True)),
            ],
            options={
                'ordering': ('post', 'mime_type', 'link'),
                'verbose_name': 'Post Enclosure',
                'verbose_name_plural': 'Post Enclosures',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Feed',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('url', models.URLField(unique=True, verbose_name='Url', db_index=True)),
                ('title', models.CharField(db_index=True, max_length=255, null=True, verbose_name='Title', blank=True)),
                ('subtitle', models.TextField(null=True, verbose_name='Subtitle', blank=True)),
                ('rights', models.CharField(max_length=255, null=True, verbose_name='Rights', blank=True)),
                ('info', models.CharField(max_length=255, null=True, verbose_name='Infos', blank=True)),
                ('language', models.CharField(max_length=50, null=True, verbose_name='Language', blank=True)),
                ('guid', models.CharField(db_index=True, max_length=32, null=True, verbose_name='Global Unique Identifier', blank=True)),
                ('icon_url', models.URLField(null=True, verbose_name='Icon URL', blank=True)),
                ('image_url', models.URLField(null=True, verbose_name='Image URL', blank=True)),
                ('etag', models.CharField(db_index=True, max_length=50, null=True, verbose_name='Etag', blank=True)),
                ('last_modified', models.DateTimeField(db_index=True, null=True, verbose_name='Last modified', blank=True)),
                ('last_checked', models.DateTimeField(null=True, verbose_name='Last checked', blank=True)),
                ('is_active', models.BooleanField(default=True, help_text='If disabled, this feed will not be further updated.', db_index=True, verbose_name='Is active')),
                ('blog', models.ForeignKey(blank=True, to='planet.Blog', null=True)),
                ('category', models.ForeignKey(blank=True, to='planet.Category', null=True)),
            ],
            options={
                'ordering': ('title',),
                'verbose_name': 'Feed',
                'verbose_name_plural': 'Feeds',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='FeedLink',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('rel', models.CharField(max_length=50, verbose_name='Relation', db_index=True)),
                ('mime_type', models.CharField(max_length=50, verbose_name='MIME type', db_index=True)),
                ('link', models.URLField(max_length=500, verbose_name='Url', db_index=True)),
                ('feed', models.ForeignKey(to='planet.Feed')),
            ],
            options={
                'ordering': ('feed', 'rel', 'mime_type'),
                'verbose_name': 'Feed Link',
                'verbose_name_plural': 'Feed Links',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Generator',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(max_length=100, verbose_name='Name')),
                ('link', models.URLField(null=True, verbose_name='Url', blank=True)),
                ('version', models.CharField(max_length=200, null=True, verbose_name='Version', blank=True)),
            ],
            options={
                'ordering': ('name', 'version'),
                'verbose_name': 'Generator',
                'verbose_name_plural': 'Generators',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Post',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('title', models.CharField(max_length=255, verbose_name='Title', db_index=True)),
                ('url', models.URLField(max_length=1000, verbose_name='Url', db_index=True)),
                ('guid', models.CharField(max_length=32, verbose_name='Guid', db_index=True)),
                ('content', models.TextField(verbose_name='Content')),
                ('comments_url', models.URLField(null=True, verbose_name='Comments URL', blank=True)),
                ('date_modified', models.DateTimeField(db_index=True, null=True, verbose_name='Date modified', blank=True)),
                ('date_created', models.DateTimeField(auto_now_add=True, verbose_name='Date created')),
            ],
            options={
                'ordering': ('-date_created', '-date_modified'),
                'verbose_name': 'Post',
                'verbose_name_plural': 'Posts',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='PostAuthorData',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('is_contributor', models.BooleanField(default=False, verbose_name='Is Contributor?')),
                ('date_created', models.DateField(auto_now_add=True, verbose_name='Date created')),
                ('author', models.ForeignKey(to='planet.Author')),
                ('post', models.ForeignKey(to='planet.Post')),
            ],
            options={
                'ordering': ('author', 'post', 'is_contributor'),
                'verbose_name': 'Post Author Data',
                'verbose_name_plural': 'Post Author Data',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='PostLink',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('rel', models.CharField(max_length=50, verbose_name='Relation', db_index=True)),
                ('mime_type', models.CharField(max_length=50, verbose_name='MIME type', db_index=True)),
                ('link', models.URLField(max_length=500, verbose_name='Url', db_index=True)),
                ('title', models.CharField(max_length=255, verbose_name='Title', db_index=True)),
                ('post', models.ForeignKey(to='planet.Post')),
            ],
            options={
                'ordering': ('post', 'title', 'rel'),
                'verbose_name': 'Post Link',
                'verbose_name_plural': 'Post Links',
            },
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name='post',
            name='authors',
            field=models.ManyToManyField(to='planet.Author', through='planet.PostAuthorData'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='post',
            name='feed',
            field=models.ForeignKey(to='planet.Feed'),
            preserve_default=True,
        ),
        migrations.AlterUniqueTogether(
            name='post',
            unique_together=set([('feed', 'guid')]),
        ),
        migrations.AlterUniqueTogether(
            name='generator',
            unique_together=set([('name', 'link', 'version')]),
        ),
        migrations.AddField(
            model_name='feed',
            name='generator',
            field=models.ForeignKey(blank=True, to='planet.Generator', null=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='feed',
            name='site',
            field=models.ForeignKey(blank=True, to='sites.Site', null=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='enclosure',
            name='post',
            field=models.ForeignKey(to='planet.Post'),
            preserve_default=True,
        ),
    ]
